@@ -1,4 +1,4 @@
-#!/usr/bin/python2
+#!/usr/bin/python3
 # -*- coding: utf-8 -*-
 #
 # Python-XRandR provides a high level API for the XRandR extension of the
@@ -227,7 +227,7 @@ class Output:
         """Returns the display height reported by the connected output device"""
         return self._info.contents.mm_height
     def get_crtc(self):
-        """Returns the xid of the hardware pipe to which the the output is
+        """Returns the xid of the hardware pipe to which the output is
            attached. If the output is disabled it will return 0"""
         return self._info.contents.crtc
     def get_crtcs(self):
@@ -907,7 +907,15 @@ class Screen:
 def get_current_display():
     """Returns the currently used display"""
     display_url = os.getenv("DISPLAY")
-    dpy = xlib.XOpenDisplay(display_url)
+    open_display = xlib.XOpenDisplay
+    # Set .argtypes and .restype, to ensure proper
+    # type check and conversion
+    open_display.restype = c_void_p
+    open_display.argtypes = [c_char_p]
+    # XOpenDisplay accepts a char*, but
+    # display_url is a unicode string therefore
+    # we convert it to a bytes string
+    dpy = open_display(display_url.encode('utf-8'))
     return dpy
 
 def get_current_screen():
