@@ -106,7 +106,7 @@ class SubmissionResult:
             }
         for context, parser in context_parsers.items():
             if context in command:
-                if not isinstance(text, str):
+                if hasattr(text, "decode"):
                     text = text.decode("utf-8")
                 stream = StringIO(text)
                 p = parser(stream)
@@ -371,7 +371,7 @@ class SubmissionParser:
                     parser(result, child)
                 else:
                     text = child.text
-                    if not isinstance(text, str):
+                    if hasattr(text, "decode"):
                         text = text.decode("utf-8")
                     stream = StringIO(text)
                     p = parser(stream)
@@ -428,9 +428,12 @@ class SubmissionParser:
 
                 lines.append("")
 
-            stream = StringIO("\n".join(lines))
-            parser = result.parseCpuinfo(stream)
-            parser.run(result)
+            if lines:
+                if hasattr(lines[0], "decode"):
+                    lines = [line.decode("utf-8") for line in lines]
+                stream = StringIO("\n".join(lines))
+                parser = result.parseCpuinfo(stream)
+                parser.run(result)
 
     def parseQuestions(self, result, node):
         """Parse the <questions> part of a submission."""
